// Copyright (C) 2021  Simon Ruderich
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package main

import (
	"testing"

	"ruderich.org/simon/safcm"
	"ruderich.org/simon/safcm/testutil"
)

func TestHostInfoRespToGroups(t *testing.T) {
	tests := []struct {
		name string
		resp safcm.MsgInfoResp
		exp  []string
	}{

		{
			"no output",
			safcm.MsgInfoResp{
				Goos:   "linux",
				Goarch: "amd64",
				Output: nil,
			},
			[]string{
				"detected_linux",
				"detected_amd64",
			},
		},

		{
			"output",
			safcm.MsgInfoResp{
				Goos:   "linux",
				Goarch: "amd64",
				Output: []string{
					"simple",
					" with spaces \t",
					"with UPPERcase",
					"with UTF-8: Hello, 世界",
				},
			},
			[]string{
				"detected_linux",
				"detected_amd64",
				"detected_simple",
				"detected_with_spaces",
				"detected_with_uppercase",
				"detected_with_utf-8_hello_",
			},
		},

		{
			"invalid goos/goarch",
			safcm.MsgInfoResp{
				Goos:   " INVALID goos! ",
				Goarch: "Hello, 世界",
				Output: nil,
			},
			[]string{
				"detected_invalid_goos_",
				"detected_hello_",
			},
		},
	}

	for _, tc := range tests {
		t.Run(tc.name, func(t *testing.T) {
			res := hostInfoRespToGroups(tc.resp)
			testutil.AssertEqual(t, "res", res, tc.exp)
		})
	}
}
